==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/StringConstantNode.h <==
// public class soot.jimple.spark.pag.StringConstantNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5773deea6ecc5e2a soot_jimple_spark_pag_AllocNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 235f588fbcf1dad8 soot_jimple_spark_pag_StringConstantNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_AllocNode

#include "soot/jimple/spark/pag/AllocNode.h"

#ifndef _JC_soot_jimple_spark_pag_StringConstantNode_H_
#define _JC_soot_jimple_spark_pag_StringConstantNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_StringConstantNode$sub_refs	_jc_soot_jimple_spark_pag_StringConstantNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_StringConstantNode$sub_nonrefs	_jc_soot_jimple_spark_pag_StringConstantNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_StringConstantNode$refs	_jc_soot_jimple_spark_pag_StringConstantNode$refs;
typedef struct _jc_soot_jimple_spark_pag_StringConstantNode$nonrefs	_jc_soot_jimple_spark_pag_StringConstantNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_StringConstantNode$object	_jc_soot_jimple_spark_pag_StringConstantNode$object;

typedef const struct _jc_soot_jimple_spark_pag_StringConstantNode$vmethods	_jc_soot_jimple_spark_pag_StringConstantNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_StringConstantNode$vtable	_jc_soot_jimple_spark_pag_StringConstantNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_StringConstantNode$vtype	_jc_soot_jimple_spark_pag_StringConstantNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_StringConstantNode$method$_init$be3769f0ccb0440f(_jc_env *, struct _jc_soot_jimple_spark_pag_StringConstantNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_StringConstantNode$method$getString$fb8e0f9b9b45f51c(_jc_env *, struct _jc_soot_jimple_spark_pag_StringConstantNode$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_StringConstantNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_StringConstantNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_StringConstantNode$method_info$getString$fb8e0f9b9b45f51c;
extern _jc_method _jc_soot_jimple_spark_pag_StringConstantNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_StringConstantNode$vmethods {
	struct _jc_java_lang_String$object	*(*getString$fb8e0f9b9b45f51c)(_jc_env *, struct _jc_soot_jimple_spark_pag_StringConstantNode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_StringConstantNode$object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_StringConstantNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_AllocNode$vmethods	soot_jimple_spark_pag_AllocNode;
	_jc_soot_jimple_spark_pag_StringConstantNode$vmethods	soot_jimple_spark_pag_StringConstantNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_StringConstantNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_StringConstantNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_StringConstantNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_StringConstantNode$refs {
    _jc_soot_jimple_spark_pag_StringConstantNode$sub_refs	soot_jimple_spark_pag_StringConstantNode;
    _jc_soot_jimple_spark_pag_AllocNode$sub_refs	soot_jimple_spark_pag_AllocNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_StringConstantNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_StringConstantNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs	soot_jimple_spark_pag_AllocNode;
    _jc_soot_jimple_spark_pag_StringConstantNode$sub_nonrefs	soot_jimple_spark_pag_StringConstantNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_StringConstantNode$object {
	_jc_soot_jimple_spark_pag_StringConstantNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_StringConstantNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_StringConstantNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_StringConstantNode$vtype _jc_soot_jimple_spark_pag_StringConstantNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_StringConstantNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_StringConstantNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_StringConstantNode_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/StringConstantNode.h <==
// public class soot.jimple.spark.pag.StringConstantNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5773deea6ecc5e2a soot_jimple_spark_pag_AllocNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 235f588fbcf1dad8 soot_jimple_spark_pag_StringConstantNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_AllocNode

#include "soot/jimple/spark/pag/AllocNode.h"

#ifndef _JC_soot_jimple_spark_pag_StringConstantNode_H_
#define _JC_soot_jimple_spark_pag_StringConstantNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_StringConstantNode$sub_refs	_jc_soot_jimple_spark_pag_StringConstantNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_StringConstantNode$sub_nonrefs	_jc_soot_jimple_spark_pag_StringConstantNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_StringConstantNode$refs	_jc_soot_jimple_spark_pag_StringConstantNode$refs;
typedef struct _jc_soot_jimple_spark_pag_StringConstantNode$nonrefs	_jc_soot_jimple_spark_pag_StringConstantNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_StringConstantNode$object	_jc_soot_jimple_spark_pag_StringConstantNode$object;

typedef const struct _jc_soot_jimple_spark_pag_StringConstantNode$vmethods	_jc_soot_jimple_spark_pag_StringConstantNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_StringConstantNode$vtable	_jc_soot_jimple_spark_pag_StringConstantNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_StringConstantNode$vtype	_jc_soot_jimple_spark_pag_StringConstantNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_StringConstantNode$method$_init$be3769f0ccb0440f(_jc_env *, struct _jc_soot_jimple_spark_pag_StringConstantNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_StringConstantNode$method$getString$fb8e0f9b9b45f51c(_jc_env *, struct _jc_soot_jimple_spark_pag_StringConstantNode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_StringConstantNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_StringConstantNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_StringConstantNode$method_info$getString$fb8e0f9b9b45f51c;
extern _jc_method _jc_soot_jimple_spark_pag_StringConstantNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_StringConstantNode$vmethods {
	struct _jc_java_lang_String$object	*(*getString$fb8e0f9b9b45f51c)(_jc_env *, struct _jc_soot_jimple_spark_pag_StringConstantNode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_StringConstantNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_StringConstantNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_AllocNode$vmethods	soot_jimple_spark_pag_AllocNode;
	_jc_soot_jimple_spark_pag_StringConstantNode$vmethods	soot_jimple_spark_pag_StringConstantNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_StringConstantNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_StringConstantNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_StringConstantNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_StringConstantNode$refs {
    _jc_soot_jimple_spark_pag_StringConstantNode$sub_refs	soot_jimple_spark_pag_StringConstantNode;
    _jc_soot_jimple_spark_pag_AllocNode$sub_refs	soot_jimple_spark_pag_AllocNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_StringConstantNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_StringConstantNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs	soot_jimple_spark_pag_AllocNode;
    _jc_soot_jimple_spark_pag_StringConstantNode$sub_nonrefs	soot_jimple_spark_pag_StringConstantNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_StringConstantNode$object {
	_jc_soot_jimple_spark_pag_StringConstantNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_StringConstantNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_StringConstantNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_StringConstantNode$vtype _jc_soot_jimple_spark_pag_StringConstantNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_StringConstantNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_StringConstantNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_StringConstantNode_H_ */
